@@ -1,7 +1,7 @@
 from typing import TypedDict, Dict, Any
 import json
 from .base_api_wrapper import RestAPIWrapper
-from wrappers.models_configurations.hugging_face_config import HuggingFaceConfiguration
+from ..models_configurations.hugging_face_config import HuggingFaceConfiguration
 
 COMPLETIONS_API_URL = "https://api-inference.huggingface.co/models"
 
@@ -27,6 +27,6 @@ class HuggingFaceWrapper(RestAPIWrapper):
     def _get_api_url(self) -> str:
         return self.api_url + '/' + self.config.model_id
 
-    def _parse_response(self, response: Dict[str, Any]) -> str:
+    def _parse_response(self, response: Dict[str, Any]) -> Dict[str, Any]:
         print (response)
         return response
\ No newline at end of file
